summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--bookmarks24
-rw-r--r--init.el43
-rw-r--r--org-clock-save.el4
3 files changed, 41 insertions, 30 deletions
diff --git a/bookmarks b/bookmarks
index a67d7d9..b1d6d22 100644
--- a/bookmarks
+++ b/bookmarks
@@ -3,18 +3,18 @@
;;; nevertheless, you probably don't want to edit it.
;;; -*- End Of Bookmark File Format Version Stamp -*-
(("org-capture-last-stored-marker"
- (filename . "~/org/cal.org")
- (front-context-string . "***** TODO Remov")
- (rear-context-string . "ue 08:30-11:00>\n")
- (position . 1167))
+ (filename . "~/org/home.org")
+ (front-context-string . "*** TODO Contact")
+ (rear-context-string . "2021-10-06 Wed]\n")
+ (position . 687))
("org-refile-last-stored"
- (filename . "~/org/cal.org")
- (front-context-string . "***** TODO Remov")
- (rear-context-string . "ue 08:30-11:00>\n")
- (position . 1167))
+ (filename . "~/org/home.org")
+ (front-context-string . "*** TODO Contact")
+ (rear-context-string . "2021-10-06 Wed]\n")
+ (position . 687))
("org-capture-last-stored"
- (filename . "~/org/work.org")
- (front-context-string . "* TODO Check out")
- (rear-context-string)
- (position . 1))
+ (filename . "~/org/home.org")
+ (front-context-string . "** TODO Contact ")
+ (rear-context-string . " Single Actions\n")
+ (position . 1188))
)
diff --git a/org-clock-save.el b/org-clock-save.el
index bd9fdd9..011c6d0 100644
--- a/org-clock-save.el
+++ b/org-clock-save.el
@@ -1,2 +1,2 @@
-;; org-clock-save.el - x220 at <2021-10-07 Thu 16:11>
-(setq org-clock-stored-history '(("/home/lemon/org/habits.org" . 368) ("/home/lemon/org/work.org" . 1422) ("/home/lemon/org/work.org" . 1) ("/home/lemon/org/work.org" . 452) ("/home/lemon/org/home.org" . 2204)))
+;; org-clock-save.el - x220 at <2021-10-09 Sat 20:58>
+(setq org-clock-stored-history '(("/home/lemon/org/work.org" . 1) ("/home/lemon/org/archive.org" . 24349) ("/home/lemon/org/archive.org" . 21942) ("/home/lemon/org/archive.org" . 13861)))
diff --git a/init.el b/init.el
index a044b18..12fde48 100644
--- a/init.el
+++ b/init.el
@@ -85,7 +85,7 @@
"url"
"COMMIT_EDITMSG\\'"))
(setq recentf-auto-cleanup 'never
- recentf-max-saved-items 1000
+ recentf-max-saved-items 50
recentf-save-file (concat user-emacs-directory ".recentf"))
(setq recentf-max-menu-items 25)
(setq recentf-max-saved-items 25)
@@ -191,7 +191,7 @@
(setq org-agenda-skip-deadline-if-done t)
(setq org-agenda-skip-scheduled-if-done t)
(setq org-reverse-note-order t)
- (setq org-habit-graph-column 35)
+ (setq org-habit-graph-column 45)
(setq org-log-done-with-time 'note)
(setq org-sort-agenda-notime-is-late nil)
(setq org-columns-default-format "%50ITEM(Task) %10CLOCKSUM %25TIMESTAMP_IA")
@@ -216,8 +216,8 @@
("tp" "Task Personal NEXT" entry (file+headline "~/org/home.org" "Single Actions")
"** NEXT %?"
:prepend t)
- ("tw" "Task Work" entry (file "~/org/work.org")
- "* TODO %?"
+ ("tw" "Task Work TODO" entry (file+headline "~/org/work.org" "Work Single Actions")
+ "** TODO %?"
:prepend t)
("tn" "Home Note" entry (file+headline "~/org/home.org" "Notes")
"** %?\n\t")
@@ -234,6 +234,8 @@
"* %?\n\t\n%i")
("wj" "Journal" entry (file+olp+datetree "~/org/work.org" "Journal")
"* %?\n\tEntered on %U\n")
+ ("i" "Idea" entry (file+headline "~/org/home.org" "Ideas")
+ "** IDEA %?\nEntered on %U\n")
("e" "Emacs Tip")
("et" "Emacs Tip" entry (file+headline "~/org/emacs-tips.org" "Emacs Tips")
"* %?\n\t%a")
@@ -246,12 +248,15 @@
(setq org-todo-keywords
(quote ((sequence "TODO(t)" "NEXT(n)" "|" "DONE(d!)")
(sequence "WAITING(w@/!)" "HOLD(h@/!)" "|" "CANCELLED(c@/!)")
+ (sequence "IDEA(i)" "|" "BADIDEA(b@/!)")
(sequence "PHONE(o)" "MEETING(m)" "PROJECT(p)"))))
(setq org-todo-keyword-faces
(quote (("TODO" :foreground "red" :weight bold)
("NEXT" :foreground "cyan" :weight bold)
("DONE" :foreground "forest green" :weight bold)
+ ("IDEA" :foreground "yellow" :weight bold)
+ ("BADIDEA" :foreground "forest green" :weight bold)
("WAITING" :foreground "orange" :weight bold)
("HOLD" :foreground "magenta" :weight bold)
("CANCELLED" :foreground "forest green" :weight bold)
@@ -361,18 +366,24 @@
(use-package magit
:bind ("C-x g" . magit-status))
-
-;; helm
-(require 'helm-config)
-(global-set-key (kbd "M-x") #'helm-M-x)
-(global-set-key (kbd "C-x r b") #'helm-filtered-bookmarks)
-(global-set-key (kbd "C-x C-f") #'helm-find-files)
-;; The default "C-x c" is quite close to "C-x C-c", which quits Emacs.
-;; Changed to "C-c h". Note: We must set "C-c h" globally, because we
-;; cannot change `helm-command-prefix-key' once `helm-config' is loaded.
-(global-set-key (kbd "C-c h") 'helm-command-prefix)
-(global-unset-key (kbd "C-x c"))
-(helm-mode 1)
+;; ido
+(setq ido-enable-flex-matching t)
+(setq ido-everywhere t)
+(setq ido-file-extensions-order '(".org" ".txt" ".py" ".emacs" ".md" ".xml" ".el" ".ini"))
+(ido-mode 1)
+
+
+;; ;; helm
+;; (require 'helm-config)
+;; (global-set-key (kbd "M-x") #'helm-M-x)
+;; (global-set-key (kbd "C-x r b") #'helm-filtered-bookmarks)
+;; (global-set-key (kbd "C-x C-f") #'helm-find-files)
+;; ;; The default "C-x c" is quite close to "C-x C-c", which quits Emacs.
+;; ;; Changed to "C-c h". Note: We must set "C-c h" globally, because we
+;; ;; cannot change `helm-command-prefix-key' once `helm-config' is loaded.
+;; (global-set-key (kbd "C-c h") 'helm-command-prefix)
+;; (global-unset-key (kbd "C-x c"))
+;; (helm-mode 1)
;; ledger mode